# Workspace Views
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/workspace-views#overview)
  * [Using Workspace Views](https://help.sap.com/docs/leanix/ea/workspace-views#using-workspace-views)
  * [Workspace Views Behavior](https://help.sap.com/docs/leanix/ea/workspace-views#workspace-views-behavior)


Use workspace views configured by admins to limit the scope of displayed information and focus on your current tasks.
